@@ -11,12 +11,12 @@
 class BipartiteGraph {
 
 public :
-    BipartiteGraph(std::vector<std::vector<bool>>& IncidenceMatrix, const std::vector<double>& Aweight, const std::vector<double>& Bweight);
+    BipartiteGraph(std::vector<std::deque<bool>>& IncidenceMatrix, const std::vector<double>& Aweight, const std::vector<double>& Bweight);
     vector<vector<size_t>> vertex_cover(const vector<size_t>& Aindex, const vector<size_t>& Bindex);
-    static std::vector<std::vector<bool>> getIncidenceMatrix(std::vector<PhyloTreeEdge>& edges1, std::vector<PhyloTreeEdge>& edges2);
+    static std::vector<std::deque<bool>> getIncidenceMatrix(std::vector<PhyloTreeEdge>& edges1, std::vector<PhyloTreeEdge>& edges2);
 
 public :
-    std::vector<std::vector<bool>> edge;
+    std::vector<std::deque<bool>> edge;
     size_t nA, nB, n;
     std::vector<Vertex> Avertex, Bvertex;
 };
